============
potranslator
============


.. image:: https://img.shields.io/pypi/v/potranslator.svg
        :target: https://pypi.python.org/pypi/potranslator
        :alt: Pypi Python Package Index Status

.. image:: https://img.shields.io/travis/SekouD/potranslator.svg
        :target: https://travis-ci.org/SekouD/potranslator
        :alt: Linux Continuous Integration Status

.. image:: https://ci.appveyor.com/api/projects/status/liecctj9hj0qwc7q/branch/master?svg=true
        :target: https://ci.appveyor.com/project/SekouD/potranslator
        :alt: Windows Continuous Integration Status

.. image:: https://readthedocs.org/projects/potranslator/badge/?version=latest
        :target: https://potranslator.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/SekouD/potranslator/shield.svg
        :target: https://pyup.io/repos/github/SekouD/potranslator/
        :alt: Depedencies Update Status

.. image:: https://codecov.io/gh/SekouD/potranslator/branch/master/graph/badge.svg
        :target: https://codecov.io/gh/SekouD/potranslator.
        :alt: Code Coverage Status

.. image:: https://snyk.io/test/github/SekouD/potranslator?targetFile=requirements.txt
        :target: https://snyk.io/test/github/SekouD/potranslator?targetFile=requirements.txt
        :alt: Code Vulnerability Status



A package to easily translate po and pot files in any language supported by Google Translate.


* Free software: MIT license
* Documentation: https://potranslator.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
